IBANInputState

Struct IBANInputState 

pub struct IBANInputState {
    pub area: Rect,
    pub inner: Rect,
    pub widget: MaskedInputState,
    pub country: String,
    pub non_exhaustive: NonExhaustive,
}
Available on crate feature iban only.
Widget state.

Fields

area: Rect

read only renewed with each render.

inner: Rect

read only renewed with each render.

widget: MaskedInputState

read+write

country: String

read only Current country mask.

non_exhaustive: NonExhaustive

Implementations

Source

impl IBANInputState

pub fn is_empty(&self) -> bool

Empty

pub fn len(&self) -> upos_type

Length in grapheme count.

pub fn line_width(&self) -> upos_type

Length as grapheme count.

pub fn set_invalid(&mut self, invalid: bool)

Renders the widget in invalid style.

pub fn get_invalid(&self) -> bool

Renders the widget in invalid style.

pub fn set_overwrite(&mut self, overwrite: bool)

The next edit operation will overwrite the current content instead of adding text. Any move operations will cancel this overwrite.

pub fn overwrite(&self) -> bool

Will the next edit operation overwrite the content?

Source

impl IBANInputState

pub fn set_clipboard(&mut self, clip: Option<impl Clipboard + 'static>)

Clipboard used. Default is to use the global_clipboard.

pub fn clipboard(&self) -> Option<&dyn Clipboard>

Clipboard used. Default is to use the global_clipboard.

pub fn copy_to_clip(&mut self) -> bool

Copy to clipboard

pub fn cut_to_clip(&mut self) -> bool

Cut to clipboard

pub fn paste_from_clip(&mut self) -> bool

Paste from clipboard.

Source

impl IBANInputState

pub fn set_undo_buffer(&mut self, undo: Option<impl UndoBuffer + 'static>)

Set undo buffer.

pub fn undo_buffer(&self) -> Option<&dyn UndoBuffer>

Undo

pub fn undo_buffer_mut(&mut self) -> Option<&mut dyn UndoBuffer>

Undo

pub fn recent_replay_log(&mut self) -> Vec<UndoEntry>

Get all recent replay recordings.

pub fn replay_log(&mut self, replay: &[UndoEntry])

Apply the replay recording.

pub fn undo(&mut self) -> bool

Undo operation

pub fn redo(&mut self) -> bool

Redo operation

Source

impl IBANInputState

pub fn set_styles(&mut self, styles: Vec<(Range<usize>, usize)>)

Set and replace all styles.

pub fn add_style(&mut self, range: Range<usize>, style: usize)

Add a style for a byte-range.

pub fn add_range_style( &mut self, range: Range<upos_type>, style: usize, ) -> Result<(), TextError>

Add a style for a Range<upos_type> . The style-nr refers to one of the styles set with the widget.

pub fn remove_style(&mut self, range: Range<usize>, style: usize)

Remove the exact TextRange and style.

pub fn remove_range_style( &mut self, range: Range<upos_type>, style: usize, ) -> Result<(), TextError>

Remove the exact Range<upos_type> and style.

pub fn styles_in( &self, range: Range<usize>, buf: &mut Vec<(Range<usize>, usize)>, )

Find all styles that touch the given range.

pub fn styles_at(&self, byte_pos: usize, buf: &mut Vec<(Range<usize>, usize)>)

All styles active at the given position.

pub fn style_match(&self, byte_pos: usize, style: usize) -> Option<Range<usize>>

Check if the given style applies at the position and return the complete range for the style.

pub fn styles(&self) -> Option<impl Iterator<Item = (Range<usize>, usize)> + '_>

List of all styles.

Source

impl IBANInputState

pub fn offset(&self) -> upos_type

Offset shown.

pub fn set_offset(&mut self, offset: upos_type)

Offset shown. This is corrected if the cursor wouldn’t be visible.

pub fn cursor(&self) -> upos_type

Cursor position

pub fn set_cursor(&mut self, cursor: upos_type, extend_selection: bool) -> bool

Set the cursor position, reset selection.

pub fn set_default_cursor(&mut self)

Place cursor at some sensible position according to the mask.

pub fn anchor(&self) -> upos_type

Selection anchor.

pub fn has_selection(&self) -> bool

Selection

pub fn selection(&self) -> Range<upos_type>

Selection

pub fn set_selection(&mut self, anchor: upos_type, cursor: upos_type) -> bool

Selection

pub fn select_all(&mut self)

Select all text.

pub fn selected_text(&self) -> &str

Selection

Source

impl IBANInputState

pub fn insert_char(&mut self, c: char) -> bool

Insert a char at the current position.

pub fn delete_range(&mut self, range: Range<upos_type>) -> bool

Remove the selected range. The text will be replaced with the default value as defined by the mask.

pub fn try_delete_range( &mut self, range: Range<upos_type>, ) -> Result<bool, TextError>

Remove the selected range. The text will be replaced with the default value as defined by the mask.

pub fn delete_next_char(&mut self) -> bool

pub fn delete_prev_char(&mut self) -> bool

Delete the char before the cursor.

Source

impl IBANInputState

pub fn move_right(&mut self, extend_selection: bool) -> bool

Move to the next char.

pub fn move_left(&mut self, extend_selection: bool) -> bool

Move to the previous char.

pub fn move_to_line_start(&mut self, extend_selection: bool) -> bool

Start of line

pub fn move_to_line_end(&mut self, extend_selection: bool) -> bool

End of line

Source

impl IBANInputState

pub fn col_to_screen(&self, pos: upos_type) -> Option<u16>

Converts a grapheme based position to a screen position relative to the widget area.

pub fn screen_to_col(&self, scx: i16) -> upos_type

Converts from a widget relative screen coordinate to a grapheme index. x is the relative screen position.

pub fn set_screen_cursor(&mut self, cursor: i16, extend_selection: bool) -> bool

Set the cursor position from a screen position relative to the origin of the widget. This value can be negative, which selects a currently not visible position and scrolls to it.

Source

impl IBANInputState

pub fn new() -> Self

New state.

pub fn named(name: &str) -> Self

pub fn clear(&mut self)

Reset to empty.

pub fn validate(&mut self) -> Result<bool, TextError>

Validate the IBAN. Sets the invalid flag. Returns true if the IBAN is valid.

pub fn set_value(&mut self, iban: impl AsRef<str>)

Set the IBAN.

Invalid IBANs are acceptable, but they will be truncated to 35 characters. If an invalid IBAN is set the widget will immediately set the invalid flag too.

pub fn value(&self) -> String

Get the IBAN.

This will return invalid IBANs too.

pub fn valid_value(&self) -> Result<String, TextError>

Get the IBAN.

This will only return valid IBANs or empty strings.