pub struct IBANInputState {
pub area: Rect,
pub inner: Rect,
pub widget: MaskedInputState,
pub country: String,
pub non_exhaustive: NonExhaustive,
}iban only.Expand description
Widget state.
Fields
area: Rectread only renewed with each render.
inner: Rectread only renewed with each render.
widget: MaskedInputStateread+write
country: Stringread only Current country mask.
non_exhaustive: NonExhaustiveImplementations
Sourceimpl IBANInputState
impl IBANInputState
Sourcepub fn line_width(&self) -> upos_type
pub fn line_width(&self) -> upos_type
Length as grapheme count.
Sourcepub fn set_invalid(&mut self, invalid: bool)
pub fn set_invalid(&mut self, invalid: bool)
Renders the widget in invalid style.
Sourcepub fn get_invalid(&self) -> bool
pub fn get_invalid(&self) -> bool
Renders the widget in invalid style.
Sourcepub fn set_overwrite(&mut self, overwrite: bool)
pub fn set_overwrite(&mut self, overwrite: bool)
The next edit operation will overwrite the current content instead of adding text. Any move operations will cancel this overwrite.
Sourceimpl IBANInputState
impl IBANInputState
Sourcepub fn set_clipboard(&mut self, clip: Option<impl Clipboard + 'static>)
pub fn set_clipboard(&mut self, clip: Option<impl Clipboard + 'static>)
Clipboard used. Default is to use the global_clipboard.
Sourcepub fn clipboard(&self) -> Option<&dyn Clipboard>
pub fn clipboard(&self) -> Option<&dyn Clipboard>
Clipboard used. Default is to use the global_clipboard.
Sourcepub fn copy_to_clip(&mut self) -> bool
pub fn copy_to_clip(&mut self) -> bool
Copy to clipboard
Sourcepub fn cut_to_clip(&mut self) -> bool
pub fn cut_to_clip(&mut self) -> bool
Cut to clipboard
Sourcepub fn paste_from_clip(&mut self) -> bool
pub fn paste_from_clip(&mut self) -> bool
Paste from clipboard.
Sourceimpl IBANInputState
impl IBANInputState
Sourcepub fn set_undo_buffer(&mut self, undo: Option<impl UndoBuffer + 'static>)
pub fn set_undo_buffer(&mut self, undo: Option<impl UndoBuffer + 'static>)
Set undo buffer.
Sourcepub fn undo_buffer(&self) -> Option<&dyn UndoBuffer>
pub fn undo_buffer(&self) -> Option<&dyn UndoBuffer>
Undo
Sourcepub fn undo_buffer_mut(&mut self) -> Option<&mut dyn UndoBuffer>
pub fn undo_buffer_mut(&mut self) -> Option<&mut dyn UndoBuffer>
Undo
Sourcepub fn recent_replay_log(&mut self) -> Vec<UndoEntry>
pub fn recent_replay_log(&mut self) -> Vec<UndoEntry>
Get all recent replay recordings.
Sourcepub fn replay_log(&mut self, replay: &[UndoEntry])
pub fn replay_log(&mut self, replay: &[UndoEntry])
Apply the replay recording.
Sourceimpl IBANInputState
impl IBANInputState
Sourcepub fn add_range_style(
&mut self,
range: Range<upos_type>,
style: usize,
) -> Result<(), TextError>
pub fn add_range_style( &mut self, range: Range<upos_type>, style: usize, ) -> Result<(), TextError>
Add a style for a Range<upos_type> .
The style-nr refers to one of the styles set with the widget.
Sourcepub fn remove_style(&mut self, range: Range<usize>, style: usize)
pub fn remove_style(&mut self, range: Range<usize>, style: usize)
Remove the exact TextRange and style.
Sourcepub fn remove_range_style(
&mut self,
range: Range<upos_type>,
style: usize,
) -> Result<(), TextError>
pub fn remove_range_style( &mut self, range: Range<upos_type>, style: usize, ) -> Result<(), TextError>
Remove the exact Range<upos_type> and style.
Sourcepub fn styles_in(
&self,
range: Range<usize>,
buf: &mut Vec<(Range<usize>, usize)>,
)
pub fn styles_in( &self, range: Range<usize>, buf: &mut Vec<(Range<usize>, usize)>, )
Find all styles that touch the given range.
Sourcepub fn styles_at(&self, byte_pos: usize, buf: &mut Vec<(Range<usize>, usize)>)
pub fn styles_at(&self, byte_pos: usize, buf: &mut Vec<(Range<usize>, usize)>)
All styles active at the given position.
Sourceimpl IBANInputState
impl IBANInputState
Sourcepub fn set_offset(&mut self, offset: upos_type)
pub fn set_offset(&mut self, offset: upos_type)
Offset shown. This is corrected if the cursor wouldn’t be visible.
Sourcepub fn set_cursor(&mut self, cursor: upos_type, extend_selection: bool) -> bool
pub fn set_cursor(&mut self, cursor: upos_type, extend_selection: bool) -> bool
Set the cursor position, reset selection.
Sourcepub fn set_default_cursor(&mut self)
pub fn set_default_cursor(&mut self)
Place cursor at some sensible position according to the mask.
Sourcepub fn has_selection(&self) -> bool
pub fn has_selection(&self) -> bool
Selection
Sourcepub fn set_selection(&mut self, anchor: upos_type, cursor: upos_type) -> bool
pub fn set_selection(&mut self, anchor: upos_type, cursor: upos_type) -> bool
Selection
Sourcepub fn select_all(&mut self)
pub fn select_all(&mut self)
Select all text.
Sourcepub fn selected_text(&self) -> &str
pub fn selected_text(&self) -> &str
Selection
Sourceimpl IBANInputState
impl IBANInputState
Sourcepub fn insert_char(&mut self, c: char) -> bool
pub fn insert_char(&mut self, c: char) -> bool
Insert a char at the current position.
Sourcepub fn delete_range(&mut self, range: Range<upos_type>) -> bool
pub fn delete_range(&mut self, range: Range<upos_type>) -> bool
Remove the selected range. The text will be replaced with the default value as defined by the mask.
Sourcepub fn try_delete_range(
&mut self,
range: Range<upos_type>,
) -> Result<bool, TextError>
pub fn try_delete_range( &mut self, range: Range<upos_type>, ) -> Result<bool, TextError>
Remove the selected range. The text will be replaced with the default value as defined by the mask.
pub fn delete_next_char(&mut self) -> bool
Sourcepub fn delete_prev_char(&mut self) -> bool
pub fn delete_prev_char(&mut self) -> bool
Delete the char before the cursor.
Sourceimpl IBANInputState
impl IBANInputState
Sourcepub fn move_right(&mut self, extend_selection: bool) -> bool
pub fn move_right(&mut self, extend_selection: bool) -> bool
Move to the next char.
Sourcepub fn move_to_line_start(&mut self, extend_selection: bool) -> bool
pub fn move_to_line_start(&mut self, extend_selection: bool) -> bool
Start of line
Sourcepub fn move_to_line_end(&mut self, extend_selection: bool) -> bool
pub fn move_to_line_end(&mut self, extend_selection: bool) -> bool
End of line
Sourceimpl IBANInputState
impl IBANInputState
Sourcepub fn col_to_screen(&self, pos: upos_type) -> Option<u16>
pub fn col_to_screen(&self, pos: upos_type) -> Option<u16>
Converts a grapheme based position to a screen position relative to the widget area.
Sourcepub fn screen_to_col(&self, scx: i16) -> upos_type
pub fn screen_to_col(&self, scx: i16) -> upos_type
Converts from a widget relative screen coordinate to a grapheme index. x is the relative screen position.
Sourcepub fn set_screen_cursor(&mut self, cursor: i16, extend_selection: bool) -> bool
pub fn set_screen_cursor(&mut self, cursor: i16, extend_selection: bool) -> bool
Set the cursor position from a screen position relative to the origin of the widget. This value can be negative, which selects a currently not visible position and scrolls to it.
Sourceimpl IBANInputState
impl IBANInputState
pub fn named(name: &str) -> Self
Sourcepub fn validate(&mut self) -> Result<bool, TextError>
pub fn validate(&mut self) -> Result<bool, TextError>
Validate the IBAN. Sets the invalid flag. Returns true if the IBAN is valid.
Sourcepub fn set_value(&mut self, iban: impl AsRef<str>)
pub fn set_value(&mut self, iban: impl AsRef<str>)
Set the IBAN.
Invalid IBANs are acceptable, but they will be truncated to 35 characters. If an invalid IBAN is set the widget will immediately set the invalid flag too.
Sourcepub fn valid_value(&self) -> Result<String, TextError>
pub fn valid_value(&self) -> Result<String, TextError>
Get the IBAN.
This will only return valid IBANs or empty strings.